@@ -22,29 +22,14 @@
 #define RICHTEXTCOMPOSER_INSERTHTMLDIALOG_H
 
 #include <QDialog>
+#include "config-kpimtextedit.h"
+
 #include "kpimtextedit_export.h"
 #include "kpimtextedit/plaintexteditor.h"
 
 namespace KPIMTextEdit
 {
-class TextEditorCompleter;
-}
-namespace KPIMTextEdit
-{
-class TextEditorCompleter;
 class InsertHtmlDialogPrivate;
-class InsertHtmlEditor : public KPIMTextEdit::PlainTextEditor
-{
-    Q_OBJECT
-public:
-    explicit InsertHtmlEditor(QWidget *parent = Q_NULLPTR);
-    ~InsertHtmlEditor();
-protected:
-    void keyPressEvent(QKeyEvent *e) Q_DECL_OVERRIDE;
-private:
-    KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter;
-};
-
 class KPIMTEXTEDIT_EXPORT InsertHtmlDialog : public QDialog
 {
     Q_OBJECT
